﻿B4J=true
Group=Default Group
ModulesStructureVersion=1
Type=Class
Version=6.01
@EndOfDesignText@
'Class Module MessageBox.
'Show a message with title. This MessageBox replaces the B4J MsgBox because on the Raspberry Pi the titlebar and borders of the dialog are not vivible.
'@author Robert W.B. Linn @ www.rwblinn.de
'@version See Class_Globals Const CLASSVERSION

'Example <copy>
'Msg.LogoPaneColor = fx.Colors.red
'Msg.Show("Error Message Example", $"[ERROR] - This is an error message."$)
'</copy>
Private Sub Class_Globals
	Private Const CLASSTITLE As String = "InputBox"		'ignore
	Private Const CLASSVERSION As String = "v20180507"		'ignore
	' Form
	Private fx As JFX
	Private Form_InputBox As Form
	' Views
	Private Label_Title As Label
	Private Pane_Logo As Pane
	Private Label_Logo As Label
	Private TextArea_Message As TextArea
	Private TextField_Input As TextField
	Private Button_Close As Button
	' Properties
	' Locals
	Private mLogoPaneColor As Paint
End Sub

'Initializes the MessageBox object.
'Parent - set the parent form
'Messages - list of messages
'Title - title of the dialog
Public Sub Initialize(Parent As Form)
	' Store init params to local class vars
	' Form
	Form_InputBox.Initialize("Form_InputBox", 500dip, 300dip)
	Form_InputBox.SetOwner(Parent)
	Form_InputBox.SetFormStyle("UNDECORATED")
	Form_InputBox.Resizable = False
	Form_InputBox.RootPane.LoadLayout("InputBox")
	Form_InputBox.Title = "MessageBox"
	mLogoPaneColor = Color_HexToPaint(CSSUtils.GetStyleProperty(Pane_Logo, "-fx-background-color"))
End Sub

#Region Form
' Show the message dialog
' Title - title shown in the header
' Message - message shown in the textarea
' Returns:
' None
' Dialog result - True|False
' Properties - FontFamily As Font, FontSize As Double, FontBold As Boolean, FontItalic As Boolean
Public Sub Show(Title As String, Message As String) As String
	Form_InputBox.Title = Title
	Label_Title.Text = Title
	TextArea_Message.Text = Message
	Button_Close.RequestFocus
	Form_InputBox.ShowAndWait
	Return TextField_Input.Text
End Sub
#End Region

#Region Buttons
Private Sub Button_Close_Click
	Form_InputBox.Close
End Sub
#End Region

#Region TextArea

#End Region

#Region TextField Input
Sub TextField_Input_Action
	Form_InputBox.Close
End Sub
#End Region

#Region Properties
' Set or get the label logo fontawesome icon
' Example settin the anchor as logo<code>
' DyK.LabelLogo = Chr(0xF13D)
' </code>
Public Sub setLabelLogo(Value As String)
	Label_Logo.Text = Value
End Sub
Public Sub getLabelLogo As String
	Return Label_Logo.Text
End Sub

' Set or get the textarea message wraptext property
Public Sub setWrapText(Value As Boolean)
	TextArea_Message.WrapText = Value
End Sub
Public Sub getWrapText As Boolean
	Return TextArea_Message.WrapText
End Sub

' Set or get the textarea message wraptext property
Public Sub setLogoPaneColor(Value As Paint)
	mLogoPaneColor = Value
	CSSUtils.SetBackgroundColor(Pane_Logo, Value)
End Sub
Public Sub getLogoPaneColor As Paint
	Return mLogoPaneColor
End Sub

' Set or get the message title
Public Sub setTitle(Value As String)
	Label_Title.Text = Value
End Sub
Public Sub getTitle As String
	Return Label_Title.Text
End Sub

' Set or get the prompt for the textfield
Public Sub setPromptText(Value As String)
	TextField_Input.PromptText = Value
End Sub
Public Sub getPromptText As String
	Return TextField_Input.PromptText
End Sub
#End Region

#Region Helpers
' Convert Hex RRGGBB to Paint.
Private Sub Color_HexToPaint(Hex As String) As Paint
	Dim r,g,b As Int
	Hex = Hex.Replace("0x", "").Replace("#", "")
	If Hex.Length = 6 Then
		r = Bit.ParseInt(Hex.SubString2(0,2), 16)
		g = Bit.ParseInt(Hex.SubString2(2,4), 16)
		b = Bit.ParseInt(Hex.SubString2(4,6), 16)
		Return fx.Colors.RGB(r, g, b)
	Else
		Return Null		
	End If
End Sub
#End Region
