﻿B4J=true
Group=Default Group
ModulesStructureVersion=1
Type=Class
Version=6.01
@EndOfDesignText@
'Class Module ListBox.
'Show a listbox with title. Scrolling through the list via buttons.
'@author Robert W.B. Linn @ www.rwblinn.de
'@version See Class_Globals Const CLASSVERSION

'Example <copy>
'Msg.LogoPaneColor = fx.Colors.red
'Msg.Show("Error Message Example", $"[ERROR] - This is an error message."$)
'</copy>
Private Sub Class_Globals
	Private Const CLASSTITLE As String = "ListBox"		'ignore
	Private Const CLASSVERSION As String = "v20180510"		'ignore
	' Form
	Private fx As JFX
	Private Form_MessageBox As Form
	' Views
	Private Label_Title As Label
	Private Pane_Logo As Pane
	Private Label_Logo As Label
	Private Button_Close As Button
	' Properties
	' Locals
	Private mLogoPaneColor As Paint
	Private ListView_Items As ListView
	Private Button_First As Button
	Private Button_Last As Button
	Private Button_Next As Button
	Private Button_Prev As Button
End Sub

'Initializes the MessageBox object.
'Parent - set the parent form
Public Sub Initialize(Parent As Form)
	' Store init params to local class vars
	' Form
	Form_MessageBox.Initialize("Form_MessageBox", 500dip, 300dip)
	Form_MessageBox.SetOwner(Parent)
	Form_MessageBox.SetFormStyle("UNDECORATED")
	Form_MessageBox.Resizable = False
	Form_MessageBox.RootPane.LoadLayout("ListBox")
	Form_MessageBox.Title = "ListBox"
	' Styling
	CSSUtils.SetBackgroundColor(Button_First, fx.Colors.Transparent)
	CSSUtils.SetBackgroundColor(Button_Next, fx.Colors.Transparent)
	CSSUtils.SetBackgroundColor(Button_Prev, fx.Colors.Transparent)
	CSSUtils.SetBackgroundColor(Button_Last, fx.Colors.Transparent)
	mLogoPaneColor = Color_HexToPaint(CSSUtils.GetStyleProperty(Pane_Logo, "-fx-background-color"))
End Sub

#Region Form
' Show the message dialog
' Title - title shown in the header
' Message - message shown in the textarea
' Returns:
' None
Public Sub Show(Title As String, Items As List)
	Form_MessageBox.Title = Title
	Label_Title.Text = Title
	ListView_Items.Items.Clear
	ListView_Items.Items.AddAll(Items)
	If ListView_Items.Items.Size > 0 Then ListView_Items.SelectedIndex = 0
	Button_Close.RequestFocus
	Form_MessageBox.ShowAndWait
End Sub
#End Region

#Region Buttons
Sub Button_Prev_Click
	If ListView_Items.SelectedIndex = -1 Then Return
	If ListView_Items.SelectedIndex > 0 Then ListView_Items.SelectedIndex = ListView_Items.SelectedIndex - 1
	ListView_Items.ScrollTo(ListView_Items.SelectedIndex)
End Sub

Sub Button_Next_Click
	If ListView_Items.SelectedIndex = -1 Then Return
	If ListView_Items.SelectedIndex < ListView_Items.Items.Size - 1 Then ListView_Items.SelectedIndex = ListView_Items.SelectedIndex + 1
	ListView_Items.ScrollTo(ListView_Items.SelectedIndex)
End Sub

Sub Button_Last_Click
	If ListView_Items.SelectedIndex = -1 Then Return
	ListView_Items.SelectedIndex = ListView_Items.Items.Size - 1
	ListView_Items.ScrollTo(ListView_Items.SelectedIndex)
End Sub

Sub Button_First_Click
	If ListView_Items.SelectedIndex = -1 Then Return
	ListView_Items.SelectedIndex = 0
	ListView_Items.ScrollTo(ListView_Items.SelectedIndex)
End Sub

Private Sub Button_Close_Click
	Form_MessageBox.Close
End Sub
#End Region

#Region LisView
Sub ListView_Items_SelectedIndexChanged(Index As Int)
' Not used	
End Sub
#End Region

#Region Actions

#End Region

#Region Properties
' Set or get the label logo fontawesome icon
' Example settin the anchor as logo<code>
' DyK.LabelLogo = Chr(0xF13D)
' </code>
Public Sub setLabelLogo(Value As String)
	Label_Logo.Text = Value
End Sub
Public Sub getLabelLogo As String
	Return Label_Logo.Text
End Sub

' Set or get the textarea message wraptext property
Public Sub setLogoPaneColor(Value As Paint)
	mLogoPaneColor = Value
	CSSUtils.SetBackgroundColor(Pane_Logo, Value)
End Sub
Public Sub getLogoPaneColor As Paint
	Return mLogoPaneColor
End Sub

' Set or get the message title
Public Sub setTitle(Value As String)
	Label_Title.Text = Value
End Sub
Public Sub getTitle As String
	Return Label_Title.Text
End Sub
#End Region

#Region Helpers
' Convert Hex RRGGBB to Paint.
Private Sub Color_HexToPaint(Hex As String) As Paint
	Dim r,g,b As Int
	Hex = Hex.Replace("0x", "").Replace("#", "")
	If Hex.Length = 6 Then
		r = Bit.ParseInt(Hex.SubString2(0,2), 16)
		g = Bit.ParseInt(Hex.SubString2(2,4), 16)
		b = Bit.ParseInt(Hex.SubString2(4,6), 16)
		Return fx.Colors.RGB(r, g, b)
	Else
		Return Null		
	End If
End Sub
#End Region
